==> pardeeVisualizationPackage-0.0.1-py3-none-any.whl: Pardee_Package/color_palletes.py <==
def DU_color_pallete():
    yellow = "#FDB813"
    orange = "#F26522"
    dark_gold = "#6d5c41"
    light_gold = "#9AA86E"
    crimson = "#7E0026"
    black = "#000000"
    color_pallete = [light_gold,
                     dark_gold,
                     yellow,
                     orange,
                     crimson,
                     black]
    return color_pallete

def crimson_color_gradient():
    yellow = "#FDB813"
    orange = "#F26522"
    light_crimson ="#7E0032"
    crimson = "#8B2332"
    dark_red = "#58001B"
    color_pallete = [yellow,
                     orange,
                     light_crimson,
                     crimson,
                     dark_red]
    
    return color_pallete

def gold_color_gradient():
    light_gold = "#EAD4AA"
    gold = "#D5BA74"
    dark_gold = "#8B6F4B"
    light_brown = "#6d5c41"
    black = "#000000"
    color_pallete = [light_gold,
                     gold,
                     dark_gold,
                     light_brown,
                     black]
    
    return color_pallete

def color_blind_friendly_color_pallete():
    dark_blue = "#006BA4"
    orange = "#FF800E"
    silver = "#ABABAB"
    dark_gray = "#595959"
    blue = "#5F9ED1"
    dark_orange = "C85200"
    gray = "#898989"
    light_blue = "#A2C8EC"
    light_orange = "#FFB579"
    light_gray = "#CFCFCF"
    color_pallete = [dark_blue,
                     orange,
                     silver,
                     dark_gray,
                     blue,
                     dark_orange,
                     gray,
                     light_blue,
                     light_orange,
                     light_gray]
    return color_pallete

def grayscale_color_pallete():
    gainsboro = "#DCDCDC"
    light_gray = "#D3D3D3"
    silver = "#C0C0C0"
    dark_gray = "#A9A9A9"
    gray = "#808080"
    dim_gray = "#696969"
    light_slate_gray = "#778899"
    slate_gray = "#708090"
    dark_slate_gray = "#2F4F4F"
    black = "#000000"
    color_pallete = [gainsboro,
                     light_gray,
                     silver,
                     dark_gray,
                     gray,
                     dim_gray,
                     light_slate_gray,
                     slate_gray,
                     dark_slate_gray,
                     black]
    return color_pallete

def off_white():
    return "#F4F3ED"

def silver():
    return "#F7F7F7"

def crimson():
    return "#7E0026"

def gold():
    return "#D5BA74"

==> pardeeVisualizationPackage-0.0.3-py3-none-any.whl: Pardee_Package/color_palletes.py <==
def DU_color_pallete():
    yellow = "#FDB813"
    orange = "#F26522"
    dark_gold = "#6d5c41"
    light_gold = "#9AA86E"
    crimson = "#7E0026"
    black = "#000000"
    color_pallete = [light_gold,
                     dark_gold,
                     yellow,
                     orange,
                     crimson,
                     black]
    return color_pallete

def crimson_color_gradient():
    yellow = "#FDB813"
    orange = "#F26522"
    light_crimson ="#7E0032"
    crimson = "#8B2332"
    dark_red = "#58001B"
    color_pallete = [yellow,
                     orange,
                     light_crimson,
                     crimson,
                     dark_red]
    
    return color_pallete

def gold_color_gradient():
    light_gold = "#EAD4AA"
    gold = "#D5BA74"
    dark_gold = "#8B6F4B"
    light_brown = "#6d5c41"
    black = "#000000"
    color_pallete = [light_gold,
                     gold,
                     dark_gold,
                     light_brown,
                     black]
    
    return color_pallete

def color_blind_friendly_color_pallete():
    dark_blue = "#006BA4"
    orange = "#FF800E"
    silver = "#ABABAB"
    dark_gray = "#595959"
    blue = "#5F9ED1"
    dark_orange = "#C85200"
    gray = "#898989"
    light_blue = "#A2C8EC"
    light_orange = "#FFB579"
    light_gray = "#CFCFCF"
    color_pallete = [dark_blue,
                     orange,
                     silver,
                     dark_gray,
                     blue,
                     dark_orange,
                     gray,
                     light_blue,
                     light_orange,
                     light_gray]
    return color_pallete


def high_contrast_color_blind_pallete():
    deep_blue = "#192238",
    orange = "#FF800E",
    silver = "#ABABAB",
    dark_gray = "#595959",
    blue = "#5F9ED1",
    dark_orange = "C85200",
    gray = "#898989",
    light_blue = "#A2C8EC",
    light_orange = "#FFB579",
    light_gray = "#CFCFCF",
    color_pallete = [deep_blue,
                     orange,
                     silver,
                     dark_gray,
                     blue,
                     dark_orange,
                     gray,
                     light_blue,
                     light_orange,
                     light_gray]
    return color_pallete

def high_contrast_color_pallete():
    dark_cyan = "#520e05",
    purple = "#E835E8",
    yellow = "#dbd91d",
    green = "#4cd411",
    orange = "#fa8b2a",
    aqua = "#08c5d1",
    seablue = "#00353f",
    gray = "#898989",
    light_blue = "#A2C8EC",
    light_orange = "#FFB579",
    light_gray = "#CFCFCF",
    color_pallete = [dark_cyan,
                     purple,
                     yellow,
                     green,
                     orange,
                     aqua,
                     seablue,
                     gray,
                     light_blue,
                     light_orange,
                     light_gray]
    return color_pallete



def grayscale_color_pallete():
    gainsboro = "#DCDCDC"
    light_gray = "#D3D3D3"
    silver = "#C0C0C0"
    dark_gray = "#A9A9A9"
    gray = "#808080"
    dim_gray = "#696969"
    light_slate_gray = "#778899"
    slate_gray = "#708090"
    dark_slate_gray = "#2F4F4F"
    black = "#000000"
    color_pallete = [gainsboro,
                     light_gray,
                     silver,
                     dark_gray,
                     gray,
                     dim_gray,
                     light_slate_gray,
                     slate_gray,
                     dark_slate_gray,
                     black]
    return color_pallete

def off_white():
    return "#F4F3ED"

def silver():
    return "#F7F7F7"

def crimson():
    return "#7E0026"

def gold():
    return "#D5BA74"
